/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 *
 *****************************************************************************/
 
package org.ow2.petals.cli.shell.command;

import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;

/**
 * This command exits the current shell with an exit code.
 * @author Sebastien Andre - EBM WebSourcing
 */
public class Exit extends AbstractCommand {

    public Exit() {
        super();
        this.setUsage("[<exit_code>]");
        this.setDescription("Exit this shell");
    }


    @Override
    public void execute(String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 1)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        try {
            int status = args.length > 0 ? Integer.parseInt(args[0]) : 0;
            this.getShell().exit(status);
        } catch (final NumberFormatException e) {
            throw new CommandException(this, e);
        }
    }

}
