/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.cli.shell.command;

import java.util.Map.Entry;
import java.util.Properties;

import org.ow2.petals.admin.api.AdminFactory;
import org.ow2.petals.admin.api.ContainerAdministration;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class PropertiesList extends AbstractCommand {

    public PropertiesList() {
        super("properties-list");
        this.setUsage("usage: properties-list");
        this.setDescription("Get the values defined in its server.properties file");
    }

    @Override
    public void execute(String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 0)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        try {
            ContainerAdministration containerAdministration = AdminFactory.newInstance().createContainerAdministration();
            Properties serverProperties = containerAdministration.getServerProperties();
            for (final Entry<Object, Object> property : serverProperties.entrySet()) {
                String key = (String) property.getKey();
                String value = (String) property.getValue();
                this.getShell().getPrintStream()
                        .println(String.format("%s: %s", key, value.isEmpty() ? "\"\"" : value));
            }
        } catch (final Exception e) {
            throw new CommandException(this, e);
        }
    }

}
