/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.cli.shell.command;

import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.CommandLineParser;
import org.apache.commons.cli.MissingArgumentException;
import org.apache.commons.cli.MissingOptionException;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.OptionBuilder;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;
import org.apache.commons.cli.PosixParser;
import org.apache.commons.cli.UnrecognizedOptionException;
import org.ow2.petals.admin.api.AdminFactory;
import org.ow2.petals.admin.api.RegistryAdministration;
import org.ow2.petals.admin.api.exception.RegistryAdministrationException;
import org.ow2.petals.cli.api.command.CommandUtil;
import org.ow2.petals.cli.api.command.exception.CommandBadArgumentNumberException;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandInvalidException;
import org.ow2.petals.cli.api.command.exception.CommandMissingArgumentException;
import org.ow2.petals.cli.api.command.exception.CommandMissingOptionsException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;

/**
 * This command registry-sync for a slave petals ESB container.
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class RegistrySync extends AbstractCommand {

    /**
     * The all option
     */
    private static final String ALL_SHORT_OPTION = "a";
    private static final String ALL_LONG_OPTION = "all";
    private static final Option ALL_OPTION = OptionBuilder.
            hasArg(false)
            .withLongOpt(ALL_LONG_OPTION)
            .withDescription("A flag to indicate to synchonize all the nodes.")
            .create(ALL_SHORT_OPTION);

    public RegistrySync() {
        super("registry-sync");
        this.setUsage(CommandUtil.formatCommandUsage(this));
		this.setDescription("Synchronize the registry");
	}

	@Override
	public void execute(String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 1)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        try {
            CommandLineParser parser = new PosixParser();
            CommandLine cmd = parser.parse(this.getOptions(), args);

            RegistryAdministration registryAdministration = AdminFactory.newInstance()
                    .createRegistryAdministration();
            if (cmd.hasOption(ALL_SHORT_OPTION)) {
                registryAdministration.synchronizeRegistryOnAllNodes();
            } else {
                registryAdministration.synchronizeRegistry();
            }
        } catch (final UnrecognizedOptionException e) {
            throw new CommandBadArgumentNumberException(this);
        } catch (final MissingArgumentException e) {
            throw new CommandMissingArgumentException(this, e.getOption());
        } catch (final MissingOptionException e) {
            throw new CommandMissingOptionsException(this, e.getMissingOptions());
        } catch (final ParseException e) {
            throw new CommandInvalidException(this, e);
        } catch (final RegistryAdministrationException e) {
            throw new CommandException(this, e);
        }
    }

    @Override
    public Options getOptions() {
        Options options = new Options();
        options.addOption(ALL_OPTION);
        return options;
    }
}
