/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.cli.shell.command;

import java.util.Arrays;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;

/**
 * This command sets the value of a property.
 * @author Sebastien Andre - EBM WebSourcing
 */
public class Set extends AbstractCommand {

    public static final Pattern REGEX_DECLARATION = Pattern
            .compile("^\\s*([-\\. \\w]+)\\s*[^\\\\][=:]?\\s*(.*)$");

    public Set() {
        super();
        this.setUsage("key [=:] value");
        this.setDescription("Assign a value to the system property named key");
    }

    @Override
    public void execute(String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 3)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        if (args.length == 0) {
            this.printProperties();

        } else {
            StringBuilder sb = new StringBuilder();
            for (String arg : args) {
                sb.append(arg);
            }

            this.parseDeclaration(sb.toString());
        }
    }

    private void parseDeclaration(String expr) throws CommandException {
        Matcher m = REGEX_DECLARATION.matcher(expr);

        if (m.matches()) {
            System.setProperty(m.group(1), m.group(2));
        } else {
            throw new CommandException(this, "invalid syntax in declaration");
        }

    }

    private void printProperties() {
        StringBuilder sb = new StringBuilder();

        String[] keys = System.getProperties().keySet().toArray(new String[0]);
        Arrays.sort(keys);
        for (String key : keys) {
            sb.append(key).append('=').append(System.getProperty(key)).append(System.getProperty( "line.separator" ));
        }

        this.getShell().getPrintStream().print(sb.toString());
    }
}
