/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.cli.shell.command;

import java.io.PrintStream;
import java.util.HashMap;

import org.ow2.petals.admin.api.AdminFactory;
import org.ow2.petals.admin.api.ContainerAdministration;
import org.ow2.petals.admin.topology.Container;
import org.ow2.petals.admin.topology.Container.PortType;
import org.ow2.petals.admin.topology.Domain;
import org.ow2.petals.admin.topology.Subdomain;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandTooManyArgumentsException;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class TopologyList extends AbstractCommand {

    public TopologyList() {
        super("topology-list");
        this.setUsage("");
        this.setDescription("Get information about the topology this node is part o");
    }

    @Override
    public void execute(String[] args) throws CommandException {
        if (!this.checkArguments(args, 0, 0)) {
            throw new CommandTooManyArgumentsException(this, args);
        }

        try {
            ContainerAdministration containerAdministration = AdminFactory.newInstance()
                    .createContainerAdministration();
            Domain domain = containerAdministration.getTopology();
            StringBuilder topologyInformation = new StringBuilder(String.format("Domain: %s\n",
                    domain.getName()));

            for (Subdomain subdomain : domain.getSubdomains()) {
                topologyInformation.append(String.format("Subdomain: %s\n", subdomain.getName()));

                for (Container container : subdomain.getContainers()) {
                    String containerInformation = String.format(
                            "* Container: %s\n** Type: %s\n** Host: %s\n",
                            container.getContainerName(), container.getNodeType().toString()
                                    .toLowerCase(), container.getHost());
                    topologyInformation.append(containerInformation);

                    HashMap<PortType, Integer> ports = container.getPorts();
                    for (PortType portType : ports.keySet()) {
                        topologyInformation.append(String.format("** %s: %d\n", portType,
                                ports.get(portType)));
                    }
                }
            }

            PrintStream out = this.getShell().getPrintStream();
            out.println(topologyInformation);
        } catch (final Exception e) {
            throw new CommandException(this, e);
        }
    }


}
