/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.cli.shell.util;

import static org.ow2.petals.cli.Constants.CommonOption.ARTIFACT_SHORT_OPTION;

import java.io.File;
import java.io.FileFilter;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

import jline.console.completer.Completer;
import jline.console.completer.StringsCompleter;

import org.apache.commons.lang.text.StrMatcher;
import org.apache.commons.lang.text.StrTokenizer;
import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.cli.api.shell.Shell;

/**
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public final class Utils {

    private Utils() {
    	// nothing
    }

    /**
     * Add file protocol, if no protocol is defined in the string.
     *
     * @param arg
     * @return
     * @throws MalformedURLException
     */
    public static final URL toURL(String arg) throws MalformedURLException {
        assert arg != null;
        URL url;
        Pattern p = Pattern.compile("^[a-zA-Z]+:/+");
        boolean containsProtocol = p.matcher(arg).find();
        if (containsProtocol) {
            url = new URL(arg);
        } else {
            url = new URL("file://" + arg);
        }
        return url;
    }

    public static final String[] getLineArgs(String line) {
        StrMatcher delim = StrMatcher.splitMatcher();
        StrMatcher quote = StrMatcher.quoteMatcher();

        StrTokenizer tokenizer = new StrTokenizer(line, delim, quote);
        String[] args = tokenizer.getTokenArray();
        return args;
    }

    public static void addArtifactTypeAndNameCompleter(final Shell shell,
            final ArtifactAdministration artifactAdministration,
            final Map<String, Completer> completers) {
        try {
            final List<String> artifactCompleterValue = new ArrayList<String>();
            for (final Artifact a : artifactAdministration.listArtifacts()) {
                artifactCompleterValue.add(a.getType() + " " + a.getName());
            }
            completers.put(ARTIFACT_SHORT_OPTION, new StringsCompleter(artifactCompleterValue));
        } catch (final Throwable e) {
            if (shell.isDebugModeEnable()) {
                e.printStackTrace();
            }
        }
    }

    /**
     * List zip files in the specifed directory and return an array of URLs
     * 
     * @param directory
     * @return return an array of URLs containing ZIP file
     * @throws IOException
     */
    public static URL[] getUrls(final File directory) throws IOException {
        final FileFilter filter = new FileFilter() {
            @Override
            public boolean accept(File pathname) {
                if (pathname.getAbsolutePath().toLowerCase().endsWith("zip")) {
                    return true;
                }
                return false;
            }
        };
        final File[] files = directory.listFiles(filter);
        if (files == null) {
            throw new FileNotFoundException(directory.getAbsolutePath()
                    + " (No such file or directory)");
        }
        final int length = files.length;
        final URL[] urls = new URL[length];
        for (int i = 0; i < length; i++) {
            urls[i] = files[i].toURI().toURL();
        }
        return urls;
    }

}
